==> haskell-microspec-0.2.1.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microspec
version: 0.2.1.3
id: microspec-0.2.1.3-EvJTZd6bZSAAYxx0mDPczQ
key: microspec-0.2.1.3-EvJTZd6bZSAAYxx0mDPczQ
license: BSD-3-Clause
maintainer: Tom Murphy
author: Tom Murphy
stability: experimental
synopsis: Tiny QuickCheck test library with minimal dependencies
description:
    A tiny (1 module, <500 lines) property-based (and unit) testing library with minimal dependencies.
    .
    Instead of reinventing the wheel (<https://xkcd.com/927>), we use a
    RSpec/HSpec-like DSL and run tests with QuickCheck.
    .
    For many use-cases, microspec is a drop-in replacement for hspec.
    .
    > import Test.Microspec
    >
    > main :: IO ()
    > main = microspec $ do
    >    describe "replicate" $ do
    >       it "doubles with 2" $
    >          replicate 2 '\''x'\'' === "xx"
    >       it "creates a list of the right size" $
    >          \(Positive n) -> length (replicate n '\''x'\'') === n
    >
    >    describe "reverse" $ do
    >       it "reverse . reverse === id" $ \l ->
    >          reverse (reverse l) === (l :: [Int])
    >
    >    describe "tail" $
    >       it "length is -1" $ \(NonEmpty l) ->
    >          length (tail l :: [Int]) === length l - 1
    >
    >    describe "solve the halting problem" $
    >       pending
category: Test, Testing
abi: ca5424d2e455ba2f25e5b415b4c8e1b3
exposed: True
exposed-modules:
    Test.Microspec
import-dirs: /usr/lib/ghc-8.6.5/site-local/microspec-0.2.1.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/microspec-0.2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microspec-0.2.1.3
hs-libraries: HSmicrospec-0.2.1.3-EvJTZd6bZSAAYxx0mDPczQ
depends:
    QuickCheck-2.13.2-26sILnMT1dV6Y2IUujSwGD base-4.12.0.0 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-microspec/html/microspec.haddock
haddock-html: /usr/share/doc/haskell-microspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-microspec-0.2.1.3-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-microspec.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: microspec
version: 0.2.1.3
id: microspec-0.2.1.3-7kZ5F8rUDVb9YafteAWdKi
key: microspec-0.2.1.3-7kZ5F8rUDVb9YafteAWdKi
license: BSD-3-Clause
maintainer: Tom Murphy
author: Tom Murphy
stability: experimental
synopsis: Tiny QuickCheck test library with minimal dependencies
description:
    A tiny (1 module, <500 lines) property-based (and unit) testing library with minimal dependencies.
    .
    Instead of reinventing the wheel (<https://xkcd.com/927>), we use a
    RSpec/HSpec-like DSL and run tests with QuickCheck.
    .
    For many use-cases, microspec is a drop-in replacement for hspec.
    .
    > import Test.Microspec
    >
    > main :: IO ()
    > main = microspec $ do
    >    describe "replicate" $ do
    >       it "doubles with 2" $
    >          replicate 2 '\''x'\'' === "xx"
    >       it "creates a list of the right size" $
    >          \(Positive n) -> length (replicate n '\''x'\'') === n
    >
    >    describe "reverse" $ do
    >       it "reverse . reverse === id" $ \l ->
    >          reverse (reverse l) === (l :: [Int])
    >
    >    describe "tail" $
    >       it "length is -1" $ \(NonEmpty l) ->
    >          length (tail l :: [Int]) === length l - 1
    >
    >    describe "solve the halting problem" $
    >       pending
category: Test, Testing
abi: d941f789545b7a4a61bc0c00da5a36a6
exposed: True
exposed-modules:
    Test.Microspec
import-dirs: /usr/lib/ghc-8.6.5/site-local/microspec-0.2.1.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/microspec-0.2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/microspec-0.2.1.3
hs-libraries: HSmicrospec-0.2.1.3-7kZ5F8rUDVb9YafteAWdKi
depends:
    QuickCheck-2.13.2-8Fp36mG21e67uRy7VcQZNU base-4.12.0.0 time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-microspec/html/microspec.haddock
haddock-html: /usr/share/doc/haskell-microspec/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
